pub struct ConstraintPoster<'solver, ConstraintImpl> { /* private fields */ }Expand description
A structure which is responsible for adding the created Constraints to the
Solver. For an example on how to use this, see crate::constraints.
Implementations
Sourceimpl<ConstraintImpl: Constraint> ConstraintPoster<'_, ConstraintImpl>
impl<ConstraintImpl: Constraint> ConstraintPoster<'_, ConstraintImpl>
Sourcepub fn post(self)
pub fn post(self)
Add the Constraint to the Solver.
Sourcepub fn implied_by(self, reification_literal: Literal)
pub fn implied_by(self, reification_literal: Literal)
Add the half-reified version of the Constraint to the Solver; i.e. post the
constraint r -> constraint where r is a reification literal.
Sourceimpl<ConstraintImpl: NegatableConstraint> ConstraintPoster<'_, ConstraintImpl>
impl<ConstraintImpl: NegatableConstraint> ConstraintPoster<'_, ConstraintImpl>
Sourcepub fn reify(self, reification_literal: Literal)
pub fn reify(self, reification_literal: Literal)
Add the reified version of the Constraint to the Solver; i.e. post the constraint
r <-> constraint where r is a reification literal.