Contains the options which can be passed to the Solver.
These influence the following aspects:
- The restart strategy of the solver
- The learned clause database management approach
- The proof logging
Re-exports
pub use crate::propagators::nogoods::LearningOptions;
Structs
- Reified
Propagator Args - A
PropagatorConstructorfor the reified propagator. - Restart
Options - The options which are used by the solver to determine when a restart should occur.
- Solver
Options - Options for the
Solverwhich determine how it behaves.
Enums
- Conflict
Resolver Type - During search, the CP solver will inevitably evaluate partial assignments that violate at least one constraint. When this happens, conflict resolution is applied to restore the solver to a state from which it can continue the search.
- Sequence
Generator Type - Specifies the type of sequence which is used to generate conflict limits before a restart occurs.