pub struct DomainEvents { /* private fields */ }Expand description
A set of DomainEvents.
Implementations
Sourceimpl DomainEvents
impl DomainEvents
Sourcepub const BOUNDS: DomainEvents
pub const BOUNDS: DomainEvents
DomainEvents with both lower and upper bound tightening (but not other value removal).
Sourcepub const ANY_INT: DomainEvents
pub const ANY_INT: DomainEvents
DomainEvents with lower and upper bound tightening, assigning to a single value, and single value removal.
Sourcepub const LOWER_BOUND: DomainEvents
pub const LOWER_BOUND: DomainEvents
DomainEvents with only lower bound tightening.
Sourcepub const UPPER_BOUND: DomainEvents
pub const UPPER_BOUND: DomainEvents
DomainEvents with only upper bound tightening.
Sourcepub const ASSIGN: DomainEvents
pub const ASSIGN: DomainEvents
DomainEvents with only assigning to a single value.
Sourceimpl DomainEvents
impl DomainEvents
pub const fn new(int_events: EnumSet<DomainEvent>) -> DomainEvents