pub struct RuntimeCheckersBuilder { /* private fields */ }Expand description
A builder for the RuntimeCheckers that ensures at least one checker is added.
Implementations
Sourceimpl RuntimeCheckersBuilder
impl RuntimeCheckersBuilder
Sourcepub fn add_inference_checker(
&mut self,
constraint_tag: ConstraintTag,
inference_label: impl InferenceLabel,
checker: impl InferenceChecker<Predicate> + 'static,
) -> InferenceCode
pub fn add_inference_checker( &mut self, constraint_tag: ConstraintTag, inference_label: impl InferenceLabel, checker: impl InferenceChecker<Predicate> + 'static, ) -> InferenceCode
Add an InferenceChecker to verify the soundness of propagations.
Sourcepub fn build(self) -> RuntimeCheckers
pub fn build(self) -> RuntimeCheckers
Finish adding runtime checkers.
Panics if runtime verification is enabled and no checkers are added. If it is expected
behavior that no checkers are added, use RuntimeCheckers::empty.