Module state

Module state 

Contains structures for the state containing the propagators and variables.

See State for more information.

Re-exports

pub use crate::propagation::CurrentNogood;
pub use crate::propagation::PropagatorId;

Structs

EmptyDomain
EmptyDomainConflict
A conflict because a domain became empty.
PropagatorConflict
A conflict stated by a propagator. A propagator that identifies a conflict that is not an empty domain, describes that conflict with this type.
PropagatorHandle
A typed wrapper around a propagator id that allows retrieving concrete propagators instead of type-erased instances Box<dyn Propagator>.
State
The State is the container of variables and propagators.

Enums

Conflict
Information concerning the conflict returned by State::propagate_to_fixed_point.