EmptyDomainConflict

Struct EmptyDomainConflict 

pub struct EmptyDomainConflict {
    pub trigger_predicate: Predicate,
    /* private fields */
}
A conflict because a domain became empty.

Fields

trigger_predicate: Predicate

The predicate that caused a domain to become empty.

Implementations

Source

impl EmptyDomainConflict

pub fn domain(&self) -> DomainId

The domain that became empty.

pub fn get_reason( &self, state: &mut State, reason_buffer: &mut (impl Extend<Predicate> + AsRef<[Predicate]>), current_nogood: CurrentNogood<'_>, )

Returns the reason for the EmptyDomainConflict::trigger_predicate being propagated to true while it is already false in the State.