pub enum Reason {
Eager(PropositionalConjunction, InferenceCode),
DynamicLazy(u64),
}Expand description
A reason for CP propagator to make a change
Variants
Eager(PropositionalConjunction, InferenceCode)
An eager reason contains the propositional conjunction with the reason, without the
propagated predicate, and the InferenceCode identifying the explanation algorithm.
DynamicLazy(u64)
A lazy reason, which is computed on-demand rather than up-front. This is also referred to as a ‘backward’ reason.
A lazy reason contains a payload that propagators can use to identify what type of
propagation the reason is for. The payload should be enough for the propagator to construct
an explanation based on its internal state. The InferenceCode is returned by
crate::propagation::Propagator::lazy_explanation on demand.