pub struct TrailedInteger { /* private fields */ }Expand description
An integer whose value is automatically restored upon backtracking to its previous value at the checkpoint to which backtracking occurred.